import { Injectable } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import { environment } from '../../environments/environment';

@Injectable({
    providedIn: 'root',
})
export class CommentService {

    constructor(private http: HttpClient) {
    }

    getRanked(target: number, page: number, size: number, ignore: string[] = []) {
        return this.http.get(environment.apiUrl + "/comments/" + target + "?page=" + page + "&size=" + size + "&ignore=" + ignore);
    }

    getRankedByParent(target: number, parent: number, page: number, size: number, ignore: string[] = []) {
        return this.http.get(environment.apiUrl + "/comments/" + target + "/" + parent + "?page=" + page + "&size=" + size + "&ignore=" + ignore);
    }

    getNew(target: number, page: number, size: number, ignore: string[] = []) {
        return this.http.get(environment.apiUrl + "/comments/new/" + target + "?page=" + page + "&size=" + size + "&ignore=" + ignore);
    }

    getNewByParent(target: number, parent: number, page: number, size: number, ignore: string[] = []) {
        return this.http.get(environment.apiUrl + "/comments/new/" + target + "/" + parent + "?page=" + page + "&size=" + size + "&ignore=" + ignore);
    }

    getByUser(username: string, page: number, size: number, ignore: string[] = []) {
        return this.http.get(environment.apiUrl + "/comments/byuser/" + username + "?page=" + page + "&size=" + size + "&ignore=" + ignore);
    }

    count(target: number) {
        return this.http.get(environment.apiUrl + "/comments/count/" + target);
    }

    countParent(target: number, parent: number) {
        return this.http.get(environment.apiUrl + "/comments/count/" + target + "/" + parent);
    }

    getComment(id: number, ignore: string[] = []) {
        return this.http.get(environment.apiUrl + "/comments/comment/" + id + "?ignore=" + ignore);
    }

    create(comment: any, ignore: string[] = []) {
        return this.http.post(environment.apiUrl + "/comments?ignore=" + ignore, comment);
    }

    update(comment: any, ignore: string[] = []) {
        return this.http.patch(environment.apiUrl + "/comments?ignore=" + ignore, comment);
    }

    delete(id: number) {
        return this.http.delete(environment.apiUrl + "/comments/" + id);
    }

}