import { Injectable } from '@angular/core';
import { HttpClient, HttpParams } from '@angular/common/http';
import { environment } from '../../environments/environment';

@Injectable({
    providedIn: 'root',
})
export class EntriesService {

    constructor(private http: HttpClient) {
    }

    fetch(path: string, page: number, size: number, asc: boolean, filter: any) {
        let httpParams = new HttpParams();
        if (page != undefined) {
            httpParams = httpParams.set("page", "" + page);
        }
        if (size != undefined) {
            httpParams = httpParams.set("size", "" + size);
        }

        if (asc) {
            httpParams = httpParams.set("asc", "" + asc);
        }

        if (filter) {
            for (const param in filter) {
                if (filter[ param ]) {
                    httpParams = httpParams.set(param, "" + filter[ param ]);
                }
            }
        }

        return this.http.get(environment.apiUrl + "/entries" + path, { params: httpParams });
    }

    getByView(name: string, page: number, size: number, asc: boolean, filter: any) {
        return this.fetch("/" + name, page, size, asc, filter);
    }

    getByUser(username: string, page: number, size: number, asc: boolean, filter: any) {
        return this.fetch("/byuser/" + username, page, size, asc, filter);
    }

    search(query: string, page: number, size: number, asc: boolean, byDate: boolean) {
        return this.fetch("/search", page, size, asc, { q: query, byDate: byDate });
    }

    getEntry(id: number) {
        return this.http.get(environment.apiUrl + "/entries/entry/" + id);
    }

    create(entry: any) {
        entry.type = 'entry';
        return this.http.post(environment.apiUrl + "/entries", entry);
    }

    update(entry: any) {
        entry.type = 'entry';
        return this.http.patch(environment.apiUrl + "/entries", entry);
    }

    delete(id: number) {
        return this.http.delete(environment.apiUrl + "/entries/" + id);
    }

    titleHelper(url: string) {
        return this.http.get(environment.apiUrl + "/entries/helper/title?url=" + encodeURIComponent(url));
    }

}