import { Injectable } from '@angular/core';
import { HttpClient, HttpParams } from '@angular/common/http';
import { environment } from '../../environments/environment';
import { ReplaySubject } from 'rxjs';
import { RequestError } from './requesterror';

@Injectable({
    providedIn: 'root',
})
export class ViewService {

    views: ReplaySubject<any> = new ReplaySubject(1);

    constructor(private http: HttpClient) {
    }

    getViews() {
        return this.http.get(environment.apiUrl + "/views").toPromise().then((data: any) => {
            this.views.next(data);
            return data;
        }, error => {
            throw new RequestError(error);
        });;
    }

    getPublicViews(page: number, size: number, desc: boolean) {
        let httpParams = new HttpParams();
        if (page != undefined) {
            httpParams = httpParams.set("page", "" + page);
        }
        if (size != undefined) {
            httpParams = httpParams.set("size", "" + size);
        }
        if (desc) {
            httpParams = httpParams.set("desc", "" + desc);
        }

        return this.http.get(environment.apiUrl + "/views/public", { params: httpParams });
    }

    getView(name: string, username: string) {
        let httpParams = new HttpParams();
        if (username != undefined) {
            httpParams = httpParams.set("user", "" + username);
        }

        return this.http.get(environment.apiUrl + "/views/view/" + name, { params: httpParams });
    }

    createOrUpdate(view: any) {
        return this.http.post(environment.apiUrl + "/views/view", view);
    }

    deleteView(name: string) {
        return this.http.delete(environment.apiUrl + "/views/view/" + name);
    }

}