import { Component, OnInit, Input } from '@angular/core';
import { Observable } from 'rxjs';

@Component({
  selector: 'ui-entries',
  templateUrl: './entries.ui.html',
  styleUrls: [ './entries.ui.scss' ]
})
export class UiEntries implements OnInit {

  @Input() entries: any;
  @Input() update: Function;
  @Input() refresh: Function;
  @Input() gravityFilter: boolean = false;
  @Input() filter: boolean = true;
  @Input() text: boolean = false;
  pageSizeOptions: number[] = [ 1, 2, 3, 4, 5, 10, 15, 30, 50, 100 ];
  filterOpen: boolean = false;
  searchTags: Observable<Object>;
  boundTagsPickerChange: Function;
  boundExcludedTagsPickerChange: Function;
  entryTypes: string[] = [ undefined, 'LINK', 'DISCUSSION', 'QUESTION', 'INTERN' ];
  tags: string[] = [];
  excludedTags: string[] = [];

  constructor() { }

  ngOnInit(): void {
    this.checkFilterOpen();
    this.boundTagsPickerChange = this.tagsPickerChange.bind(this);
    this.boundExcludedTagsPickerChange = this.excludedTagsPickerChange.bind(this);
  }

  checkFilterOpen() {
    this.filterOpen = false;
    if (this.entries.filter) {
      for (const param in this.entries.filter) {
        if (this.entries.filter[ param ]) {
          this.filterOpen = true;
        }

        if (param == 'tags' && this.entries.filter[ param ]) {
          this.tags = this.entries.filter[ param ].split(',');
        }
        if (param == 'excludedTags' && this.entries.filter[ param ]) {
          this.excludedTags = this.entries.filter[ param ].split(',');
        }
      }
    }
  }

  tagsPickerChange(value: string[]) {
    if (value && value.length > 0) {
      this.setFilter('tags', value.join(','));
    } else {
      this.setFilter('tags', undefined);
    }
  }

  excludedTagsPickerChange(value: string[]) {
    if (value && value.length > 0) {
      this.setFilter('excludedTags', value.join(','));
    } else {
      this.setFilter('excludedTags', undefined);
    }
  }

  setFilter(key: string, value) {
    if (value != this.entries.filter[ key ]) {
      this.entries.filter[ key ] = value;
      this.entries.number = 0;
      this.update({ pageIndex: this.entries.number, pageSize: this.entries.size, length: this.entries.totalElements });
    }
  }
}
